@@ -35,7 +35,7 @@
 #include <unistd.h>
 #include <errno.h>
 #include <signal.h>
-#include <wait.h>
+#include <sys/wait.h>
 #include <time.h>
 
 #include <glib.h>
@@ -207,27 +207,33 @@ char * plug_get_path(desc)
  return _plug_get_path(desc);
 }
 
-
-
-void plug_set_fname(desc, filename)
- struct arglist * desc;
- const char * filename;
+/**
+ * @brief Sets CACHEFILE in the given arglist.
+ *
+ * @param desc The arglist where the entry is to be created.
+ * @param cachefile The value for CACHEFILE (a filename).
+ */
+void plug_set_cachefile(desc, cachefile)
+  struct arglist * desc;
+  const char * cachefile;
 {
- arg_add_value(desc, "FILENAME", ARG_STRING, strlen(filename), estrdup(filename));
+  arg_add_value(desc, "CACHEFILE", ARG_STRING, strlen(cachefile),
+                estrdup(cachefile));
 }
 
-char * _plug_get_fname(struct arglist * desc)
+/**
+ * @brief Retrieves CACHEFILE from the given arglist.
+ *
+ * @param desc The arglist where CACHEFILE is to be searched.
+ *
+ * @return The value for CACHEFILE (a filename).
+ */
+char * plug_get_cachefile(desc)
+  struct arglist * desc;
 {
- return arg_get_value(desc, "FILENAME");
+  return arg_get_value(desc, "CACHEFILE");
 }
 
-char * plug_get_fname(desc)
- struct arglist * desc;
-{
- return _plug_get_fname(desc);
-}
-
-
 void plug_set_id(desc, id)
  struct arglist * desc;
  int id;
@@ -251,19 +257,11 @@ void plug_set_id(desc, id)
 #endif
 }
 
-int
-_plug_get_id(desc)
- struct arglist * desc;
+int plug_get_id(struct arglist * desc)
 {
  return GPOINTER_TO_SIZE(arg_get_value(desc, "ID"));
 }
 
-int
-plug_get_id(struct arglist * desc)
-{
- return _plug_get_id(desc);	/* Never cached */
-}
-
 void plug_set_oid(desc, id)
   struct arglist * desc;
   char *id;
@@ -280,16 +278,9 @@ void plug_set_oid(desc, id)
  } 
 }
 
-char *
-_plug_get_oid(desc)
- struct arglist * desc;
-{
- return arg_get_value(desc, "OID");
-}
-
 char * plug_get_oid(struct arglist * desc)
 {
-  return _plug_get_oid(desc);
+  return arg_get_value(desc, "OID");
 }
 
 void plug_set_cve_id(desc, id)
@@ -516,17 +507,11 @@ void plug_require_key(desc, keyname)
  }
 }
 
-struct arglist * _plug_get_required_keys(desc)
- struct arglist * desc;
-{
- return arg_get_value(desc, "required_keys");
-}
-
 
 struct arglist * plug_get_required_keys(desc)
  struct arglist * desc;
 {
- return _plug_get_required_keys(desc);
+  return arg_get_value(desc, "required_keys");
 }
 
 
@@ -547,17 +532,10 @@ void plug_exclude_key(desc, keyname)
  }
 }
 
-struct arglist * _plug_get_excluded_keys(desc)
- struct arglist * desc;
-{
- return arg_get_value(desc, "excluded_keys");
-}
-
-
 struct arglist * plug_get_excluded_keys(desc)
  struct arglist * desc;
 {
- return _plug_get_excluded_keys(desc);
+  return arg_get_value(desc, "excluded_keys");
 }
 
 void plug_require_port(desc, portname)
@@ -579,16 +557,10 @@ void plug_require_port(desc, portname)
  }
 }
 
-struct arglist * _plug_get_required_ports(desc)
- struct arglist * desc;
-{
- return arg_get_value(desc, "required_ports");
-}
-
 struct arglist * plug_get_required_ports(desc)
  struct arglist * desc;
 {
- return _plug_get_required_ports(desc);
+  return arg_get_value(desc, "required_ports");
 }
 
 
@@ -611,16 +583,10 @@ void plug_require_udp_port(desc, portname)
  }
 }
 
-struct arglist * _plug_get_required_udp_ports(desc)
- struct arglist * desc;
-{
- return arg_get_value(desc, "required_udp_ports");
-}
-
 struct arglist * plug_get_required_udp_ports(desc)
  struct arglist * desc;
 {
- return _plug_get_required_udp_ports(desc);
+  return arg_get_value(desc, "required_udp_ports");
 }
  
 
@@ -641,22 +607,10 @@ void plug_set_dep(desc, depname)
  }
 }
 
-
-
-struct arglist * _plug_get_deps(desc)
- struct arglist * desc;
-{
- return arg_get_value(desc, "DEPENDENCIES");
-}
-
-
 struct arglist * plug_get_deps(desc)
  struct arglist * desc;
 {
- return _plug_get_deps(desc);
-#if 0
- return store_fetch_dependencies(desc);
-#endif
+  return arg_get_value(desc, "DEPENDENCIES");
 }
 
 void plug_set_timeout(desc, timeout)
@@ -666,24 +620,12 @@ void plug_set_timeout(desc, timeout)
     arg_add_value(desc, "TIMEOUT", ARG_INT, sizeof(gpointer), GSIZE_TO_POINTER(timeout));
 }
 
-
-int _plug_get_timeout(desc)
- struct arglist * desc;
-{
- return GPOINTER_TO_SIZE(arg_get_value(desc, "TIMEOUT"));
-}
-
-
 int plug_get_timeout(desc)
  struct arglist * desc;
 {
- return _plug_get_timeout(desc);
-#if 0
- return store_fetch_timeout(desc);
-#endif
+  return GPOINTER_TO_SIZE(arg_get_value(desc, "TIMEOUT"));
 }
 
-		
 
 void plug_set_launch(desc, launch)
  struct arglist * desc;
@@ -729,17 +671,10 @@ void plug_set_name(desc, name, language)
   }
 }
 
-char * _plug_get_name(desc)
- struct arglist * desc;
-{
- return arg_get_value(desc, "NAME");
-}
-
 char * plug_get_name(desc)
  struct arglist * desc;
 {
- return _plug_get_name(desc);
- /*return store_fetch_name(desc);*/
+  return arg_get_value(desc, "NAME");
 }
 
 
@@ -869,16 +804,10 @@ void plug_set_category(desc, category)
        arg_add_value(desc, "CATEGORY", ARG_INT, sizeof(gpointer), GSIZE_TO_POINTER(category));
 }
 
-int _plug_get_category(desc)
- struct arglist * desc;
-{
- return GPOINTER_TO_SIZE(arg_get_value(desc, "CATEGORY"));	/* We don't cache this one */
-}
-
 int plug_get_category(desc)
  struct arglist * desc;
 {
- return _plug_get_category(desc);
+ return GPOINTER_TO_SIZE(arg_get_value(desc, "CATEGORY"));
 }
 
 
@@ -2073,15 +2002,6 @@ find_in_path(name, safe)
   return NULL;
 }
 
-int 
-is_shell_command_present(name)
- char * name;
-{
-  return find_in_path(name, 0) != NULL;
-}
-
-
-
 int shared_socket_register ( struct arglist * args, int fd, char * name )
 {
  int soc; 
