@@ -114,9 +114,16 @@ struct arglist * str2arglist(char * str)
 }
 
 
-
-
-/*-----------------------------------------------------------------------------*/	
+/**
+ * Copies content of one string into the other.
+ * Does not check nul-termination.
+ * @param str Source string, might be NULL.
+ * @param dst Destination string.
+ * @param sz max number of bytes to copy into dst.
+ * @param path Filename path for error message (!?).
+ * @param item Description of what had to be copied for error message (!?).
+ * @return 0 on success, -1 otherwise.
+ */
 static int safe_copy(char * str, char * dst, int sz, char * path, char * item)
 {
  if(str == NULL)	/* empty strings are OK */
@@ -133,36 +140,68 @@ static int safe_copy(char * str, char * dst, int sz, char * path, char * item)
  strcpy(dst, str); /* RATS: ignore */
  return 0;
 }
-/*-----------------------------------------------------------------------------*/
-
-
-#define MODE_SYS 0
-#define MODE_USR 1
-
-static char sys_store_dir[MAXPATHLEN+1];
-static char usr_store_dir[MAXPATHLEN+1];
-
-static int current_mode = -1;
-
 
+/*
+ * store_dir holds the directory name for the cache. If run with older
+ * installations of OpenVAS (<=2.0.0), then it is initialized with
+ * the NVT directory (server preference "plugins_folder")
+ * and appends "/.desc/". For newer versions it is the directory
+ * specified as server preference "cache_folder".
+ */
+static char store_dir[MAXPATHLEN+1] = "";
 
 /**
- * Inits the sys_store_dir string to the default value. sys_store_dir holds the 
- * path of the .desc (~server-side plugin cache) directory which is a subfolder
- * of the plugin- directory. If the .desc directory does not exist, it will be 
- * created. Also sets the mode to MODE_SYS.
- * @param dir Path to the (plugin)- directory
- * @return 0 in case of success, -1 if the directory does not exist and could 
- *         not be created.
+ * @brief Sets the @ref store_dir to the given path.
+ *
+ * @param dir Path to the cache-directory. It must exist.
+ *
+ * @return    0  in case of success (@ref store_dir is set now)
+ *            -1 if the given path exeeds the buffer size
+ *            -2 if the directory does not exist
+ *            -3 if the given path was NULL
+ *            In any other case than 0 @ref store_dir is
+ *            not set and a error is printed to stderr
+ */
+int store_init(char * dir)
+{
+  struct stat st;
+  int i = 0;
+
+  if (dir == NULL) {
+    fprintf(stderr, "store_init(): called with NULL\n");
+    return -3;
+  }
+
+  for (;i < sizeof(store_dir) && dir[i];i ++) ;
+  if (i == sizeof(store_dir)) {
+    fprintf(stderr,
+            "store_init(): path too long with more than %d characters\n", i);
+    return -1;
+  }
+
+  if (stat(dir, &st) < 0) { // check for existance
+    fprintf(stderr, "stat(%s): %s\n", dir, strerror(errno));
+    return -2;
+  }
+
+  strncpy(store_dir, dir, sizeof(store_dir));
+
+  return 0;
+}
+
+/**
+ * @brief Deprecated function to set the directory where the plugin cache files are placed.
+ *
+ * Don't use this method anymore. It is here only for legacy to be compatible with
+ * openvas-server <= 2.0.0.
+ * The new method to use is @ref store_init .
  */
 int store_init_sys(char * dir)
 {
- current_mode = MODE_SYS;
- 
- snprintf(sys_store_dir, sizeof(sys_store_dir), "%s/.desc", dir); /* RATS: ignore */
- if((mkdir(sys_store_dir, 0755) < 0) && (errno != EEXIST))
+ snprintf(store_dir, sizeof(store_dir), "%s/.desc", dir); /* RATS: ignore */
+ if((mkdir(store_dir, 0755) < 0) && (errno != EEXIST))
  {
-  fprintf(stderr, "mkdir(%s) : %s\n", sys_store_dir, strerror(errno));
+  fprintf(stderr, "mkdir(%s) : %s\n", store_dir, strerror(errno));
   return -1;
  }
  
@@ -170,60 +209,46 @@ int store_init_sys(char * dir)
 }
 
 /**
- * Inits the sys_store_dir string to the default value. sys_store_dir holds the 
- * path of the .desc (~server-side plugin cache) directory which is a subfolder
- * of the plugin- directory. If the .desc directory does not exist, it will be 
- * created. Also sets the mode to MODE_USR.
- * @param dir Path to the (plugin)- directory
- * @return 0 in case of success, -1 if the directory does not exist and could 
- *         not be created.
+ * @brief Deprecated function to set the directory where the plugin cache files are placed.
+ *
+ * Don't use this method anymore. It is here only for legacy to be compatible with
+ * openvas-server <= 2.0.0.
+ * The new method to use is @ref store_init .
  */
 int store_init_user(char * dir)
 {
- current_mode = MODE_USR;
- snprintf(usr_store_dir, sizeof(usr_store_dir), "%s/.desc", dir); /* RATS: ignore */
- if((mkdir(usr_store_dir, 0755) < 0) && (errno != EEXIST))
- {
-  fprintf(stderr, "mkdir(%s) : %s\n", usr_store_dir, strerror(errno));
-  return -1;
- } 
- 
- return 0;
+  return store_init_sys(dir);
 }
 
+/**
+ * @brief Internal function to load plugin description from cache file
+ *
+ * @param plugin    This structure is filled with the loaded plugin data
+ *
+ * @param pprefs    This structure is filled with the loaded
+ *                  plugin preferences.
+ *
+ * @param prefs     Plugin preference arglist.
+ *
+ * @param desc_file The full path to the cache file.
 
-
-/*--------------------------------------------------------------------------------*/
-
-
-static int store_get_plugin_f(struct plugin * plugin, struct pprefs * pprefs, char * dir, char * file)
+ * @return -1 upon failure, 0 for success.
+ */
+static int store_get_plugin_f(struct plugin * plugin, struct pprefs * pprefs,
+  gchar * desc_file)
 {
  int fd;
  struct plugin * p;
  struct stat st;
  int len;
- char file_name[MAXPATHLEN+1];
- char * str;
  
  bzero(plugin, sizeof(*plugin));
  plugin->id = -1;
  
- if(dir == NULL || dir[0] == '\0' || file == NULL || file[0] == '\0')
- 	return -1;
- 
- snprintf(file_name, sizeof(file_name), "%s/%s", dir, file); /* RATS: ignore */
- str = strrchr(file_name, '.');
- if(str != NULL)
- {
-  str[0] = '\0';
-  if(strlen(file_name) + 6 < sizeof(file_name))
-  	strncat(file_name, ".desc", MAXPATHLEN); /* RATS: ignore */
- }
+  if(desc_file == NULL || desc_file[0] == '\0')
+    return -1;
 
- if(file == NULL)
-  return -1;
-  
- fd = open(file_name, O_RDONLY);
+ fd = open(desc_file, O_RDONLY);
  if(fd < 0)
   return -1;
  
@@ -263,35 +288,38 @@ static int store_get_plugin_f(struct plugin * plugin, struct pprefs * pprefs, ch
 }
 
 
-int store_get_plugin(struct plugin * p, char * name)
+int store_get_plugin(struct plugin * p, char * desc_file)
 {
- int e = store_get_plugin_f(p, NULL, usr_store_dir, name);
- if(p->id < 0)
-  return store_get_plugin_f(p, NULL, sys_store_dir, name);
- else
-  return e;
+  return store_get_plugin_f(p, NULL, desc_file);
 }
 
-/*--------------------------------------------------------------------------------*/
-/* Returns a (plugin) arglist assembled from the description file .desc or NULL
- * if
+
+/**
+ * @brief Returns a (plugin) arglist assembled from the cached description file
+ *
+ * @param dir Path to location of plugin file
+ *
+ * @param file Filename of the plugin (e.g. "detect_openvas.nasl"
+ *             or "subdir1/subdir2/scriptname.nasl" ).
+ *
+ * @param prefs Plugin preference arglist.
+ *
+ * NULL is returned in either of these cases:
  * 1) the .desc does not exist
  * 2) Nvt definition file (e.g. xyz.nasl) or nvt signature (xyz.asc) file is
  *       newer than the .desc file
  * 3) the magic number test failed (other file format expected).
- * 4) an error occured.
- * @param dir Path to parent directory of the .desc directory.
- * @param file File name of the plugin (e.g. detect_openvas.nasl ).
- * @param prefs Plugin preference arglist.
- * @return Pointer to plugin as arglist or NULL (see above).
+ * 4) an internal error occured.
+ *
+ * @return Pointer to plugin as arglist or NULL.
  */
-struct arglist * store_load_plugin(char * dir, char * file,  struct arglist * prefs)
+struct arglist * store_load_plugin(char * dir, char * file,
+  struct arglist * prefs)
 {
- char desc_file[MAXPATHLEN+1];
- char plug_file[MAXPATHLEN+1];
- char asc_file[MAXPATHLEN+1];
- char * str;
- char store_dir[MAXPATHLEN+1];
+  gchar * dummy = g_build_filename(store_dir, file, NULL);
+  gchar * desc_file = g_strconcat(dummy, ".desc", NULL);
+  gchar * plug_file = g_build_filename(dir, file, NULL);
+  gchar * asc_file = g_strconcat(dummy, ".asc", NULL);
  struct plugin p;
  struct pprefs pp[MAX_PREFS];
  
@@ -302,37 +330,24 @@ struct arglist * store_load_plugin(char * dir, char * file,  struct arglist * pr
         stat_asc;
  struct arglist * al;
  
+  g_free(dummy);
+
+  if (desc_file == NULL || asc_file == NULL || plug_file == NULL) {
+    g_free(desc_file);
+    g_free(asc_file);
+    g_free(plug_file);
+    return NULL; // g_build_filename failed
+  }
+
  bzero(pp, sizeof(pp));
 
- /* Assemble file paths to stat them later */
- snprintf(desc_file, sizeof(desc_file), "%s/.desc/%s", dir, file); /* RATS: ignore */
- str = strrchr(desc_file, '.');
- if( str != NULL )
- {
-  str[0] = '\0';
-  if(	strlen(desc_file) + 6 < sizeof(desc_file) )
-  	strncat(desc_file, ".desc", MAXPATHLEN); /* RATS: ignore */
- }
-
- snprintf(asc_file, sizeof(asc_file), "%s/%s", dir, file); /* RATS: ignore */
-
- if( strlen(asc_file) + 5 < sizeof(desc_file) )
- {
-   strncat(asc_file, ".asc", MAXPATHLEN); /* RATS: ignore */
- }
- else
- {
-   /* Certificate file name is longer than MAXPATHLEN, should not happen */
-   return NULL;
- }
-
- snprintf(plug_file, sizeof(plug_file), "%s/%s", dir, file); /* RATS: ignore */
-
  /* Plugin and cache file have to exist */
- if (  stat(plug_file, &stat_plug) < 0 || stat(desc_file, &stat_desc) < 0)
-   {
+ if (  stat(plug_file, &stat_plug) < 0 || stat(desc_file, &stat_desc) < 0) {
+   g_free(desc_file);
+   g_free(asc_file);
+   g_free(plug_file);
    return NULL;
-   }
+ }
 
  /* 
   * Look if the plugin (.nasl/.oval etc) or the signature (.asc) is newer than
@@ -340,10 +355,12 @@ struct arglist * store_load_plugin(char * dir, char * file,  struct arglist * pr
   * the plugin and signatures mtime is not in the future...
   */
  if( stat_plug.st_mtime > stat_desc.st_mtime 
-    && stat_asc.st_mtime  > stat_desc.st_mtime )
-   {
-	return NULL;
-   }
+    && stat_asc.st_mtime  > stat_desc.st_mtime ) {
+   g_free(desc_file);
+   g_free(asc_file);
+   g_free(plug_file);
+   return NULL;
+ }
 
  /* 
   * Look if a signature file (.asc) exists. If so and it is newer than
@@ -351,27 +368,26 @@ struct arglist * store_load_plugin(char * dir, char * file,  struct arglist * pr
   */ 
  if(    stat(asc_file, &stat_asc) 
      && stat_asc.st_mtime > stat_desc.st_mtime 
-     && stat_asc.st_mtime <= time(NULL) )
-   {
-     return NULL;
-   }
+     && stat_asc.st_mtime <= time(NULL) ) {
+    g_free(desc_file);
+    g_free(asc_file);
+    g_free(plug_file);
+    return NULL;
+  }
 
+  if((store_get_plugin_f(&p, pp, desc_file) < 0) ||
+     (p.magic != MAGIC) ||
+     (p.oid == NULL)) {
+    g_free(desc_file);
+    g_free(asc_file);
+    g_free(plug_file);
+    return NULL;
+  }
 
- snprintf(store_dir, sizeof(store_dir), "%s/.desc", dir); /* RATS: ignore */
- if(store_get_plugin_f(&p, pp, store_dir, file) < 0)
-  return NULL;
-
-
- if(p.magic != MAGIC)
- 	return NULL;
-	
- if(p.oid == NULL) return NULL;
-
-  
  ret = emalloc(sizeof(struct arglist));   
  plug_set_oid(ret, p.oid);
  plug_set_category(ret, p.category);
- plug_set_fname(ret, file);
+ plug_set_cachefile(ret, desc_file);
  plug_set_path(ret, p.path);
  plug_set_family(ret, p.family, NULL);
  plug_set_sign_key_ids(ret, p.sign_key_ids);
@@ -408,162 +424,135 @@ struct arglist * store_load_plugin(char * dir, char * file,  struct arglist * pr
   }
  }
 
+  g_free(desc_file);
+  g_free(asc_file);
+  g_free(plug_file);
+
  return ret;
 }
 
-
-#define OLD_CVE_SZ 128
-#define OLD_BID_SZ 64
-#define OLD_XREF_SZ 512
-
-struct arglist * store_plugin(struct arglist * plugin, char * file)
+/**
+ * @brief Creates a entry in the store for data of "plugin" into cache file "file"
+ * which is placed in the cache directory.
+ *
+ * @param plugin    Data structure that contains a plugin description
+ * @param file      Name of corresponding plugin file (e.g. "x.nasl", "x.nes"
+ *                  or "x.oval". It can also be something like
+ *                  "subdir1/subdir2/scriptname.nasl").
+ */
+void store_plugin(struct arglist * plugin, char * file)
 {
- char desc_file[MAXPATHLEN+1];
- char path[MAXPATHLEN+1];
+  gchar * dummy = g_build_filename(store_dir, file, NULL);
+  gchar * desc_file = g_strconcat(dummy, ".desc", NULL);
+  // assume there is a ".desc" at the end in the store_dir path
+  // in order to guess the path of the actual plugin:
+  gchar * path = g_build_filename(store_dir, "..", file, NULL);
  struct plugin plug;
  struct pprefs pp[MAX_PREFS+1];
  char  * str;
- char * dir;
  struct arglist * arglist, * prefs;
  int e;
  int fd;
  int num_plugin_prefs = 0;
- 
- if( current_mode == MODE_SYS )
-   dir = sys_store_dir;
-  else
-   dir = usr_store_dir;
-   
-  if(strlen(file) + 2 > sizeof(path))
-  	return NULL;
- 
- strncpy(path, dir, sizeof(path) - 2 - strlen(file));
- str = strrchr(path, '/');
- if(str != NULL)
- {
-  str[0] = '\0';
- }
- strcat(path, "/");
- strcat(path, file); /* RATS: ignore */
 
- 
- 
- snprintf(desc_file, sizeof(desc_file), "%s/%s", dir, file); /* RATS: ignore */
- str = strrchr(desc_file, '.');
- if( str != NULL )
- {
-  str[0] = '\0';
-  if(strlen(desc_file) + 6 < sizeof(desc_file) )
-  	strncat(desc_file, ".desc", MAXPATHLEN); /* RATS: ignore */
- }
+  g_free(dummy);
+
+  if (desc_file == NULL || path == NULL) return; // g_build_filename failed
 
- 
- 
  bzero(&plug, sizeof(plug));
  bzero(pp, sizeof(pp));
  
  plug.magic = MAGIC;
- plug.id = _plug_get_id(plugin);
- e = safe_copy(path, plug.path, sizeof(plug.path), path, "path"); 
- if(e < 0)return NULL;
+ plug.id = plug_get_id(plugin);
+ str = plug_get_path(plugin);
+ e = safe_copy(str, plug.path, sizeof(plug.path), path, "path"); 
+ if(e < 0) return;
  
- str = _plug_get_oid(plugin);
+ str = plug_get_oid(plugin);
  e = safe_copy(str, plug.oid, sizeof(plug.oid), path, "oid");
- if(e < 0)return NULL;
+ if(e < 0) return;
 
  
- plug.timeout = _plug_get_timeout(plugin);
- plug.category = _plug_get_category(plugin);
+ plug.timeout = plug_get_timeout(plugin);
+ plug.category = plug_get_category(plugin);
  
- str = _plug_get_name(plugin);
+ str = plug_get_name(plugin);
  e = safe_copy(str, plug.name, sizeof(plug.name), path, "name");
- if(e < 0)return NULL;
+ if(e < 0) return;
  
  
  str = _plug_get_version(plugin);
  e = safe_copy(str, plug.version, sizeof(plug.version), path, "version");
- if(e < 0)return NULL;
+ if(e < 0) return;
  
  
  str = _plug_get_summary(plugin);
  e = safe_copy(str, plug.summary, sizeof(plug.summary), path, "summary");
- if(e < 0)return NULL;
+ if(e < 0) return;
  
  str = _plug_get_description(plugin);
  e = safe_copy(str, plug.description, sizeof(plug.description), path, "description");
- if(e < 0)return NULL;
+ if(e < 0) return;
  
  str = _plug_get_copyright(plugin);
  e = safe_copy(str, plug.copyright, sizeof(plug.copyright), path, "copyright");
- if(e < 0)return NULL;
+ if(e < 0) return;
  
  str = _plug_get_family(plugin);
  e = safe_copy(str, plug.family, sizeof(plug.family), path, "family");
- if(e < 0)return NULL;
+ if(e < 0) return;
  
  str = _plug_get_cve_id(plugin);
-#ifdef DEBUG_STORE
- if ( str != NULL && strlen(str) > OLD_CVE_SZ )
-	fprintf(stderr, "WARNING! CVE size will be too long for older versions of Nessus!\n");
-#endif
-	
+
  e = safe_copy(str, plug.cve_id, sizeof(plug.cve_id), path, "cve_id");
- if(e < 0)return NULL;
+ if(e < 0) return;
  
  str = _plug_get_bugtraq_id(plugin);
-#ifdef DEBUG_STORE
- if ( str != NULL && strlen(str) > OLD_BID_SZ)
-	fprintf(stderr, "WARNING! BID size will be too long for older versions of Nessus!\n");
-#endif
  e = safe_copy(str, plug.bid, sizeof(plug.bid), path, "bugtraq id");
- if(e < 0)return NULL;
+ if(e < 0) return;
  
  str = _plug_get_xref(plugin);
-#ifdef DEBUG_STORE
- if ( str != NULL && strlen(str) > OLD_XREF_SZ)
-	fprintf(stderr, "WARNING! BID size will be too long for older versions of Nessus!\n");
-#endif
  e = safe_copy(str, plug.xref, sizeof(plug.xref), path, "xref id");
- if(e < 0)return NULL;
+ if(e < 0) return;
 
  str = _plug_get_tag(plugin);
  e = safe_copy(str, plug.tag, sizeof(plug.tag), path, "tag");
- if(e < 0)return NULL;
+ if(e < 0) return;
  
- arglist = _plug_get_deps(plugin);
+ arglist = plug_get_deps(plugin);
  str = arglist2str(arglist);
  e = safe_copy(str, plug.dependencies, sizeof(plug.dependencies), path, "dependencies");
  efree(&str);
- if(e < 0)return NULL;
+ if(e < 0) return;
  
- arglist = _plug_get_required_keys(plugin);
+ arglist = plug_get_required_keys(plugin);
  str = arglist2str(arglist);
  e = safe_copy(str, plug.required_keys, sizeof(plug.required_keys), path, "required keys");
  efree(&str);
- if(e < 0)return NULL;
+ if(e < 0) return;
  
- arglist = _plug_get_excluded_keys(plugin);
+ arglist = plug_get_excluded_keys(plugin);
  str = arglist2str(arglist);
  e = safe_copy(str, plug.excluded_keys, sizeof(plug.excluded_keys), path, "excluded_keys");
  efree(&str);
- if(e < 0)return NULL;
+ if(e < 0) return;
  
- arglist = _plug_get_required_ports(plugin);
+ arglist = plug_get_required_ports(plugin);
  str = arglist2str(arglist);
  e = safe_copy(str, plug.required_ports, sizeof(plug.required_ports), path, "required ports");
  efree(&str);
- if(e < 0)return NULL;
+ if(e < 0) return;
  
- arglist = _plug_get_required_udp_ports(plugin);
+ arglist = plug_get_required_udp_ports(plugin);
  str = arglist2str(arglist);
  e = safe_copy(str, plug.required_udp_ports, sizeof(plug.required_udp_ports), path, "required udp ports");
  efree(&str);
- if(e < 0)return NULL;
+ if(e < 0) return;
 
  str = plug_get_sign_key_ids(plugin);
  e = safe_copy(str, plug.sign_key_ids, sizeof(plug.sign_key_ids), path, "key ids of signatures");
  //efree(&str);
- if(e < 0)return NULL;
+ if(e < 0) return;
  
  
  prefs = arg_get_value(plugin, "preferences");
@@ -571,7 +560,7 @@ struct arglist * store_plugin(struct arglist * plugin, char * file)
  arglist = arg_get_value(plugin, "PLUGIN_PREFS");
  if( arglist != NULL )
  {
-  char * p_name = _plug_get_name(plugin);
+  char * p_name = plug_get_name(plugin);
   
   while(arglist->next != NULL)
   {
@@ -584,18 +573,18 @@ struct arglist * store_plugin(struct arglist * plugin, char * file)
    str[0] = '\0';
    name = str + 1;
    e = safe_copy(type, pp[num_plugin_prefs].type, sizeof(pp[num_plugin_prefs].type), path, "preference-type");
-   if(e < 0)return NULL;
+   if(e < 0) return;
    e = safe_copy(name, pp[num_plugin_prefs].name, sizeof(pp[num_plugin_prefs].name), path, "preference-name");
-   if(e < 0)return NULL;
+   if(e < 0) return;
    e = safe_copy(dfl, pp[num_plugin_prefs].dfl, sizeof(pp[num_plugin_prefs].dfl), path, "preference-default");
-   if(e < 0)return NULL;
+   if(e < 0) return;
    num_plugin_prefs ++;
   
    
    if(num_plugin_prefs >= MAX_PREFS)
    {
     fprintf(stderr, "%s: too many preferences\n", path);
-    return NULL;
+    return;
    }
    _add_plugin_preference(prefs, p_name, name, type, dfl);
    str[0] = '/';
@@ -607,75 +596,56 @@ struct arglist * store_plugin(struct arglist * plugin, char * file)
   plug.has_prefs = 1;
  
  fd = open(desc_file, O_RDWR|O_CREAT|O_TRUNC, 0644);
- if(fd < 0)
- { 
-  return NULL;
- }
- 
- if(write(fd, &plug, sizeof(plug)) < 0)
- {
-  perror("write ");
- }
- 
- if(num_plugin_prefs > 0)
- {
-  write(fd, pp, sizeof(pp));
- }
- close(fd); 
- 
- 
+  if(fd < 0) { // second try: maybe the directory was missing.
+    gchar * desc_dir = g_path_get_dirname(desc_file);
 
+    if ((mkdir(desc_dir, 0755) < 0) && (errno != EEXIST)) {
+     fprintf(stderr, "mkdir(%s) : %s\n", desc_dir, strerror(errno));
+     return;
+    }
+    g_free(desc_dir);
+    fd = open(desc_file, O_RDWR|O_CREAT|O_TRUNC, 0644);
+    if(fd < 0) return;
+  }
+ 
+  if(write(fd, &plug, sizeof(plug)) < 0)
+    perror("write ");
+ 
+  if(num_plugin_prefs > 0)
+    write(fd, pp, sizeof(pp));
+  close(fd); 
+ 
  arg_set_value(plugin, "preferences", -1, NULL);
  arg_free_all(plugin);
- return NULL;
-}
 
+  g_free(desc_file);
+  g_free(path);
+}
 
 /*---------------------------------------------------------------------*/
 
 
 char * store_fetch_path(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
  return p.path;
 }
 
-
-char * store_fetch_name(struct arglist * desc)
-{
- char * fname = _plug_get_fname(desc);
- static struct plugin p;
- 
- store_get_plugin(&p, fname);
- return p.name;
-}
-
-
 char * store_fetch_version(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
  return p.version;
 }
 
-int store_fetch_timeout(struct arglist * desc)
-{
- char * fname = _plug_get_fname(desc);
- static struct plugin p;
- 
- store_get_plugin(&p, fname);
- return p.timeout;
-}
-
-
 char * store_fetch_summary(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
@@ -684,7 +654,7 @@ char * store_fetch_summary(struct arglist * desc)
 
 char * store_fetch_description(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
@@ -698,7 +668,7 @@ int store_fetch_category(struct arglist * desc)
 
 char * store_fetch_copyright(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
@@ -707,7 +677,7 @@ char * store_fetch_copyright(struct arglist * desc)
 
 char * store_fetch_family(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
@@ -716,7 +686,7 @@ char * store_fetch_family(struct arglist * desc)
 
 char * store_fetch_oid(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
@@ -725,7 +695,7 @@ char * store_fetch_oid(struct arglist * desc)
 
 char * store_fetch_cve_id(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
@@ -734,7 +704,7 @@ char * store_fetch_cve_id(struct arglist * desc)
 
 char * store_fetch_bugtraq_id(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
@@ -744,7 +714,7 @@ char * store_fetch_bugtraq_id(struct arglist * desc)
 
 char * store_fetch_xref(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
@@ -753,27 +723,16 @@ char * store_fetch_xref(struct arglist * desc)
 
 char * store_fetch_tag(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  
  store_get_plugin(&p, fname);
  return p.tag;
 }
 
-struct arglist * store_fetch_dependencies(struct arglist * desc)
-{
- char * fname = _plug_get_fname(desc);
- static struct plugin p;
- struct arglist * ret;
- 
- store_get_plugin(&p, fname);
- ret = str2arglist(p.dependencies);
- return ret; 
-}
-
 struct arglist * store_fetch_required_keys(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  struct arglist * ret;
  
@@ -784,7 +743,7 @@ struct arglist * store_fetch_required_keys(struct arglist * desc)
 
 struct arglist * store_fetch_excluded_keys(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  struct arglist * ret;
  
@@ -795,7 +754,7 @@ struct arglist * store_fetch_excluded_keys(struct arglist * desc)
 
 struct arglist * store_fetch_required_ports(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  struct arglist * ret;
  
@@ -806,7 +765,7 @@ struct arglist * store_fetch_required_ports(struct arglist * desc)
 
 struct arglist * store_fetch_required_udp_ports(struct arglist * desc)
 {
- char * fname = _plug_get_fname(desc);
+ char * fname = plug_get_cachefile(desc);
  static struct plugin p;
  struct arglist * ret;
  
