@@ -54,10 +54,8 @@ int store_save_end();
 int store_get_plugin(struct plugin *, char * );
 struct arglist * store_save_plugin(struct arglist * plugin, char * path);
 char * store_fetch_path(struct arglist * desc);
-char * store_fetch_name(struct arglist * desc);
 char * store_fetch_oid(struct arglist *);
 char * store_fetch_version(struct arglist * desc);
-int store_fetch_timeout(struct arglist * desc);
 char * store_fetch_summary(struct arglist * desc);
 char * store_fetch_description(struct arglist * desc);
 int store_fetch_category(struct arglist * desc);
@@ -67,7 +65,6 @@ char * store_fetch_cve_id(struct arglist * desc);
 char * store_fetch_bugtraq_id(struct arglist * desc);
 char * store_fetch_xref(struct arglist * desc);
 char * store_fetch_tag(struct arglist * desc);
-struct arglist * store_fetch_dependencies(struct arglist * desc);
 struct arglist * store_fetch_required_keys(struct arglist * desc);
 struct arglist * store_fetch_excluded_keys(struct arglist * desc);
 struct arglist * store_fetch_required_ports(struct arglist * desc);
